@@ -20,7 +20,7 @@ library = Library('kotti_tinymce', 'static')
 kotti_tinymce = Resource(library,
                          "kotti_tinymce.js",
                          minified="kotti_tinymce.min.js",
-                         depends=[tinymce, tinymcepopup])
+                         depends=[tinymce, ])
 
 
 @view_defaults(context=object,
@@ -75,6 +75,8 @@ class KottiTinyMCE():
                  renderer="kotti_tinymce:templates/kottibrowser.pt")
     def kottibrowser(self):
 
+        tinymcepopup.need()
+
         scales = [{
             "size": size,
             "value": name,
@@ -145,4 +147,4 @@ def kotti_configure(settings):
 def includeme(config):
     edit_needed.add(kotti_tinymce)
     config.scan("kotti_tinymce")
-    config.add_translation_dirs('kotti_tinymce:locale/')
\ No newline at end of file
+    config.add_translation_dirs('kotti_tinymce:locale/')
